==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property recordRowPath Path to the top-level parent that contains the records.
 */
public data class
AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs(
    public val recordRowPath: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs> {
    override fun toJava():
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.builder()
            .recordRowPath(recordRowPath.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs].
 */
@PulumiTagMarker
public class
AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgsBuilder
internal constructor() {
    private var recordRowPath: Output<String>? = null

    /**
     * @param value Path to the top-level parent that contains the records.
     */
    @JvmName("bptrturitkcupxjr")
    public suspend fun recordRowPath(`value`: Output<String>) {
        this.recordRowPath = value
    }

    /**
     * @param value Path to the top-level parent that contains the records.
     */
    @JvmName("mmsfnkjtmahnjvhj")
    public suspend fun recordRowPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recordRowPath = mapped
    }

    internal fun build():
        AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs =
        AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs(
            recordRowPath = recordRowPath ?: throw PulumiNullFieldException("recordRowPath"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property recordRowPath Path to the top-level parent that contains the records.
 */
public data class
AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs(
    public val recordRowPath: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs.builder()
            .recordRowPath(recordRowPath.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs].
 */
@PulumiTagMarker
public class
AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgsBuilder
internal constructor() {
    private var recordRowPath: Output<String>? = null

    /**
     * @param value Path to the top-level parent that contains the records.
     */
    @JvmName("nquhxygtgeaowyxk")
    public suspend fun recordRowPath(`value`: Output<String>) {
        this.recordRowPath = value
    }

    /**
     * @param value Path to the top-level parent that contains the records.
     */
    @JvmName("ixhpomiamckhppin")
    public suspend fun recordRowPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recordRowPath = mapped
    }

    internal fun build(): AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs =
        AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJsonArgs(
            recordRowPath = recordRowPath ?: throw PulumiNullFieldException("recordRowPath"),
        )
}
